import { IAspect } from 'aws-cdk-lib';
import { IConstruct } from 'constructs';
/**
 * Ensures that Lambda log groups are created for all Lambda functions that the
 * aspect applies to.
 *
 * @example
 *
 * import { App, Aspects } from 'aws-cdk-lib';
 * import { CreateLambdaLogGroup } from '@cdklabs/cdk-proserve-lib/aspects';
 *
 * const app = new App();
 *
 * Aspects.of(app).add(new CreateLambdaLogGroup());
 */
export declare class CreateLambdaLogGroup implements IAspect {
    /**
     * Visits a construct and creates a log group if the construct is a Lambda function.
     * @param node The construct being visited
     */
    visit(node: IConstruct): void;
}
