import { IAspect } from 'aws-cdk-lib';
import { RetentionDays } from 'aws-cdk-lib/aws-logs';
import { IConstruct } from 'constructs';
/**
 * Properties for configuring log retention settings
 */
export interface SetLogRetentionProps {
    /**
     * The retention period for the logs
     */
    readonly period: RetentionDays;
}
/**
 * Aspect that sets the log retention period for CloudWatch log groups to a
 * user-supplied retention period.
 *
 * @example
 *
 * import { App, Aspects } from 'aws-cdk-lib';
 * import { RetentionDays } from 'aws-cdk-lib/aws-logs';
 * import { SetLogRetention } from '@cdklabs/cdk-proserve-lib/aspects';
 *
 * const app = new App();
 *
 * Aspects.of(app).add(
 *   new SetLogRetention({ period: RetentionDays.EIGHTEEN_MONTHS })
 * );
 */
export declare class SetLogRetention implements IAspect {
    private readonly props;
    /**
     * Creates a new instance of SetLogRetention
     * @param props Configuration properties for log retention
     */
    constructor(props: SetLogRetentionProps);
    /**
     * Visits a construct and sets log retention if applicable
     * @param node The construct being visited
     */
    visit(node: IConstruct): void;
}
